# Introduction
This repository contains the Python SDK for the
[Eventline](https://www.exograd.com/products/eventline) platform.

# Examples
The `examples` directory contains scripts demonstrating various use cases for
the `eventline` package. All of them expect the `EVENTLINE_API_KEY` to be set.

# Contact
If you find a bug or have any question, feel free to open a GitHub issue or
contact our support by email.
